// Generated by ResgenSwift.Tags 1.2

import UIKit
import MatomoTracker
import Firebase

// MARK: - Protocol

protocol AnalyticsManagerProtocol {
    func logScreen(name: String, path: String)
    func logEvent(name: String)
}

// MARK: - Matomo

class MatomoAnalyticsManager: AnalyticsManagerProtocol {
    
    // MARK: - Properties

    private var tracker: MatomoTracker

    // MARK: - Init

    init(siteId: String, url: String) {
        debugPrint("[Matomo service] Server URL: \(url)")
        debugPrint("[Matomo service] Site ID: \(siteId)")
        tracker = MatomoTracker(siteId: siteId, baseURL: URL(string: url)!)
        
        #if DEBUG
            tracker.dispatchInterval = 5
        #endif
        
        #if DEBUG
            tracker.logger = DefaultLogger(minLevel: .verbose)
        #endif

        debugPrint("[Matomo service] Configured with content base: \(tracker.contentBase?.absoluteString ?? "-")")
        debugPrint("[Matomo service] Opt out: \(tracker.isOptedOut)")
    }
    
    // MARK: - Methods

    func logScreen(name: String, path: String) {
        guard !tracker.isOptedOut else { return }
        guard let trackerUrl = tracker.contentBase?.absoluteString else { return }
        let urlString = URL(string: "\(trackerUrl)" + "/" + "\(path)" + "iOS")
        tracker.track(
            view: [name],
            url: urlString
        )
    }

    func logEvent(name: String) {
        guard !tracker.isOptedOut else { return }
        tracker.track(
            eventWithCategory: "category",
            action: "action",
            name: name,
            number: nil,
            url: nil
        )
    }
}

// MARK: - Firebase

class FirebaseAnalyticsManager: AnalyticsManagerProtocol {
    func logScreen(name: String, path: String) {
        Analytics.logEvent(AnalyticsEventScreenView, parameters: [AnalyticsParameterScreenName: name])
    }

    func logEvent(name: String) {
        var parameters = [
            AnalyticsParameterValue: name
        ]
        
        Analytics.logEvent(AnalyticsEventSelectContent, parameters: parameters)
    }
}

// MARK: - Manager

class AnalyticsManager {
    static var shared = AnalyticsManager()
    
    // MARK: - Properties

    var managers: [AnalyticsManagerProtocol] = []

    private var isEnabled: Bool = true

    // MARK: - Methods

    func setAnalyticsEnabled(_ enable: Bool) { isEnabled = enable }

    func configure(sideId: String, url: String) {
        managers.append(MatomoAnalyticsManager(siteId: sideId, url: url))

        managers.append(FirebaseAnalyticsManager())
    }
        
    private func logScreen(name: String, path: String) {
        guard isEnabled else { return }
        managers.forEach { manager in
            manager.logScreen(name: name, path: path)
        }
    }
    
    private func logEvent(name: String) {
        guard isEnabled else { return }
        managers.forEach { manager in
            manager.logEvent(name: name)
        }
    }

    // MARK: - ScreenTag

    func logScreenEcranUn() {
        logScreen(name: "Ecran un", path: "ecran_un/")
    }

    func logEventEcranDeux() {
        logEvent(name: "Ecran deux")
    }
}
